==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/da/d59/sign__widget_8h.js <==
var sign__widget_8h =
[
    [ "QueryEditSignWidgets", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706", [
      [ "WID_QES_CAPTION", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706add3f4f1c758b7c88352800f40d42df16", null ],
      [ "WID_QES_TEXT", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ada330ace6a0869d542da63f8d0822c0e", null ],
      [ "WID_QES_OK", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a57e9314f37a6c100535052aac1bae73f", null ],
      [ "WID_QES_CANCEL", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a4d0a47f13f2fe2905ec4e2be3aead711", null ],
      [ "WID_QES_DELETE", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ac3dfa14dd7e9d535586dc3312220230e", null ],
      [ "WID_QES_PREVIOUS", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a1e834ee4410b69e9625582feff8a0985", null ],
      [ "WID_QES_NEXT", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ac38ad1de552e626aa5405c728f8af74a", null ]
    ] ],
    [ "SignListWidgets", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6", [
      [ "WID_SIL_CAPTION", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6aca0a6211861183842246d56f70e6f23e", null ],
      [ "WID_SIL_LIST", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6acae6da2fef56ffac957edf6f898111b8", null ],
      [ "WID_SIL_SCROLLBAR", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6a04a8e65487a4596812f092d997030564", null ],
      [ "WID_SIL_FILTER_TEXT", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6ac773e476ec96892b83d5ac9dce523f00", null ],
      [ "WID_SIL_FILTER_MATCH_CASE_BTN", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6a78e734c3af009e3fe8191e5309fb5007", null ],
      [ "WID_SIL_FILTER_ENTER_BTN", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6ab365a1ccabab5d8d0920ec99fb1d8fa4", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/da/d59/sign__widget_8h.js <==
var sign__widget_8h =
[
    [ "QueryEditSignWidgets", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706", [
      [ "WID_QES_CAPTION", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706add3f4f1c758b7c88352800f40d42df16", null ],
      [ "WID_QES_LOCATION", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a397df80a896761988bab075913a59a10", null ],
      [ "WID_QES_TEXT", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ada330ace6a0869d542da63f8d0822c0e", null ],
      [ "WID_QES_OK", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a57e9314f37a6c100535052aac1bae73f", null ],
      [ "WID_QES_CANCEL", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a4d0a47f13f2fe2905ec4e2be3aead711", null ],
      [ "WID_QES_DELETE", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ac3dfa14dd7e9d535586dc3312220230e", null ],
      [ "WID_QES_PREVIOUS", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706a1e834ee4410b69e9625582feff8a0985", null ],
      [ "WID_QES_NEXT", "da/d59/sign__widget_8h.html#a7bd4bf26964efd4378d6ab04ffa0b706ac38ad1de552e626aa5405c728f8af74a", null ]
    ] ],
    [ "SignListWidgets", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6", [
      [ "WID_SIL_CAPTION", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6aca0a6211861183842246d56f70e6f23e", null ],
      [ "WID_SIL_LIST", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6acae6da2fef56ffac957edf6f898111b8", null ],
      [ "WID_SIL_SCROLLBAR", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6a04a8e65487a4596812f092d997030564", null ],
      [ "WID_SIL_FILTER_TEXT", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6ac773e476ec96892b83d5ac9dce523f00", null ],
      [ "WID_SIL_FILTER_MATCH_CASE_BTN", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6a78e734c3af009e3fe8191e5309fb5007", null ],
      [ "WID_SIL_FILTER_ENTER_BTN", "da/d59/sign__widget_8h.html#a0a7a7f13d6e32d41881cba81c2c786a6ab365a1ccabab5d8d0920ec99fb1d8fa4", null ]
    ] ]
];
